The VARNA applet is used to create nice plots of predicted RNA secondary structure [1]

[1] VARNA: Interactive drawing and editing of the RNA secondary structure, Kévin Darty, Alain Denise and Yann Ponty, Bioinformatics, pp. 1974-1975, Vol. 25, no. 15, 2009
